@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLAINTEXTEDITORWIDGET_H
-#define PLAINTEXTEDITORWIDGET_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 #include <QWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditor;
 class PlainTextEditorWidgetPrivate;
 /**
@@ -24,7 +24,7 @@ class KPIMTEXTEDIT_EXPORT PlainTextEditorWidget : public QWidget
 public:
     explicit PlainTextEditorWidget(QWidget *parent = nullptr);
     explicit PlainTextEditorWidget(PlainTextEditor *customEditor, QWidget *parent = nullptr);
-    ~PlainTextEditorWidget();
+    ~PlainTextEditorWidget() override;
 
     Q_REQUIRED_RESULT PlainTextEditor *editor() const;
 
@@ -43,10 +43,10 @@ private Q_SLOTS:
     void slotReplace();
 
     void slotHideFindBar();
+
 private:
     void init(PlainTextEditor *customEditor = nullptr);
-    PlainTextEditorWidgetPrivate *const d;
+    std::unique_ptr<PlainTextEditorWidgetPrivate> const d;
 };
 }
 
-#endif // PLAINTEXTEDITORWIDGET_H
